@@ -84,7 +84,6 @@ load_lab <- function(file, merge_id = "EMPI", sep = ":", id_length = "standard",
   DATA$lab_source       <- pretty_text(data_raw$Source, remove_after = FALSE, remove_punc = FALSE, remove_white = FALSE)
   DATA$lab_accession    <- pretty_text(data_raw$Accession, remove_after = FALSE, remove_punc = FALSE, remove_white = FALSE)
 
-  DATA <- remove_column(dt = DATA, na = na, identical = identical)
-
+  if(dim(DATA)[1] != 1) {DATA <- remove_column(dt = DATA, na = na, identical = identical)}
   return(DATA)
 }
