@@ -66,7 +66,6 @@ load_rfv <- function(file, merge_id = "EMPI", sep = ":", id_length = "standard",
   DATA$rfv_comment          <- pretty_text(data_raw$Comments, remove_after = FALSE, remove_punc = FALSE, remove_white = FALSE)
   DATA$rfv_enc_num          <- pretty_text(data_raw$Encounter_number, remove_after = FALSE, remove_punc = FALSE, remove_white = FALSE)
 
-  DATA <- remove_column(dt = DATA, na = na, identical = identical)
-
+  if(dim(DATA)[1] != 1) {DATA <- remove_column(dt = DATA, na = na, identical = identical)}
   return(DATA)
 }
